@@ -36,42 +36,49 @@ class Command {
     UString m_tag0;
     UString m_tag1;
     int m_tag2;
+    UString m_tag3;
+    UString m_tag4;
     IDebugger::VariableSafePtr m_var;
     sigc::slot_base m_slot;
+    bool m_should_emit_signal;
 
 public:
 
-    Command ()  :
-        m_tag2 (0),
-        m_slot (0)
+    Command () :
+    m_tag2 (0),
+      m_slot (0),
+      m_should_emit_signal (true)
     {
         clear ();
     }
 
     /// \param a_value a textual command to send to the debugger.
     Command (const UString &a_value) :
-        m_value (a_value),
-        m_tag2 (0),
-        m_slot (0)
+    m_value (a_value),
+      m_tag2 (0),
+      m_slot (0),
+      m_should_emit_signal (true)
     {
     }
 
     Command (const UString &a_name, const UString &a_value) :
-        m_name (a_name),
-        m_value (a_value),
-        m_tag2 (0),
-        m_slot (0)
+    m_name (a_name),
+      m_value (a_value),
+      m_tag2 (0),
+      m_slot (0),
+      m_should_emit_signal (true)
     {
     }
 
     Command (const UString &a_name,
              const UString &a_value,
              const UString &a_cookie) :
-        m_cookie (a_cookie),
-        m_name (a_name),
-        m_value (a_value),
-        m_tag2 (0),
-        m_slot (0)
+    m_cookie (a_cookie),
+      m_name (a_name),
+      m_value (a_value),
+      m_tag2 (0),
+      m_slot (0),
+      m_should_emit_signal (true)
     {
     }
 
@@ -97,6 +104,12 @@ public:
     int tag2 () const {return m_tag2;}
     void tag2 (int a_in) {m_tag2 = a_in;}
 
+    const UString& tag3 () const {return m_tag3;}
+    void tag3 (const UString &a_in) {m_tag3 = a_in;}
+
+    const UString& tag4 () const {return m_tag4;}
+    void tag4 (const UString &a_in) {m_tag4 = a_in;}
+
     void variable (const IDebugger::VariableSafePtr a_in) {m_var = a_in;}
     IDebugger::VariableSafePtr variable () const {return m_var;}
 
@@ -117,6 +130,9 @@ public:
         return reinterpret_cast<const T&> (m_slot);
     }
 
+    bool should_emit_signal () const {return m_should_emit_signal;}
+    void should_emit_signal (bool a) {m_should_emit_signal = a;}
+
     /// @}
 
     void clear ()
@@ -125,6 +141,10 @@ public:
         m_value.clear ();
         m_tag0.clear ();
         m_tag1.clear ();
+        m_tag2 = 0;
+        m_tag3.clear ();
+        m_tag4.clear ();
+	m_should_emit_signal = true;
     }
 
 };//end class Command
@@ -199,6 +219,7 @@ public:
         bool m_has_stream_record;
         StreamRecord m_stream_record;
         bool m_is_stopped;
+	bool m_is_running;
         IDebugger::StopReason m_stop_reason;
         bool m_has_frame;
         IDebugger::Frame m_frame;
@@ -273,6 +294,9 @@ public:
         bool is_stopped () const {return m_is_stopped;}
         void is_stopped (bool a_in) {m_is_stopped = a_in;}
 
+	bool is_running () const {return m_is_running;}
+        void is_running (bool a) {m_is_running = a;}
+
         IDebugger::StopReason stop_reason () const {return m_stop_reason;}
         UString stop_reason_as_str () const
         {
@@ -308,6 +332,7 @@ public:
             m_has_stream_record = false;
             m_stream_record.clear ();
             m_is_stopped = false;
+            m_is_running = false;
             m_stop_reason = IDebugger::UNDEFINED_REASON;
             m_has_frame = false;
             m_frame.clear ();
@@ -340,7 +365,7 @@ public:
 
     private:
         Kind m_kind;
-        map<int, IDebugger::BreakPoint> m_breakpoints;
+        map<int, IDebugger::Breakpoint> m_breakpoints;
         map<UString, UString> m_attrs;
 
         //call stack listed members
@@ -394,6 +419,10 @@ public:
         size_t m_memory_address;
         bool m_has_memory_values;
 
+        // asm instruction list
+        std::list<common::Asm> m_asm_instrs;
+        bool m_has_asm_instrs;
+
         // Variable Object
         IDebugger::VariableSafePtr m_variable;
         bool m_has_variable;
@@ -414,6 +443,10 @@ public:
         UString m_path_expression;
         bool m_has_path_expression;
 
+        // The variable format of a variable object
+        IDebugger::Variable::Format m_variable_format;
+        bool m_has_variable_format;
+
     public:
         ResultRecord () {clear ();}
 
@@ -448,12 +481,16 @@ public:
             m_memory_values.clear ();
             m_memory_address = 0;
             m_has_memory_values = false;
+            m_asm_instrs.clear ();
+            m_has_asm_instrs = false;
             m_has_variable = false;
             m_nb_variable_deleted = 0;
             m_has_variable_children = false;
             m_has_changed_var_list = false;
             m_path_expression.clear ();
             m_has_path_expression = false;
+            m_variable_format = IDebugger::Variable::UNDEFINED_FORMAT;
+            m_has_variable_format = false;
         }
 
         /// \name accessors
@@ -462,11 +499,11 @@ public:
         Kind kind () const {return m_kind;}
         void kind (Kind a_in) {m_kind = a_in;}
 
-        const map<int, IDebugger::BreakPoint>& breakpoints () const
+        const map<int, IDebugger::Breakpoint>& breakpoints () const
         {
             return m_breakpoints;
         }
-        map<int, IDebugger::BreakPoint>& breakpoints () {return m_breakpoints;}
+        map<int, IDebugger::Breakpoint>& breakpoints () {return m_breakpoints;}
 
         map<UString, UString>& attrs () {return m_attrs;}
         const map<UString, UString>& attrs () const {return m_attrs;}
@@ -537,6 +574,20 @@ public:
             has_memory_values (true);
         }
 
+        bool has_asm_instruction_list () const {return m_has_asm_instrs;}
+        void has_asm_instruction_list (bool a) {m_has_asm_instrs = a;}
+
+        const std::list<common::Asm>& asm_instruction_list () const
+        {
+            return m_asm_instrs;
+        }
+        void asm_instruction_list
+                            (const std::list<common::Asm> &a_asms)
+        {
+            m_asm_instrs = a_asms;
+            m_has_asm_instrs = true;
+        }
+
         const map<int, list<IDebugger::VariableSafePtr> >&
                                                     frames_parameters () const
         {
@@ -715,6 +766,25 @@ public:
             m_has_path_expression = a;
         }
 
+        IDebugger::Variable::Format variable_format () const
+        {
+            return m_variable_format;
+        }
+        void variable_format (IDebugger::Variable::Format a_format)
+        {
+            m_variable_format = a_format;
+            has_variable_format (true);
+        }
+
+        bool has_variable_format () const
+        {
+            return m_has_variable_format;
+        }
+        void has_variable_format (bool a_flag)
+        {
+            m_has_variable_format = a_flag;
+        }
+
         /// @}
 
     };//end class ResultRecord
@@ -862,7 +932,6 @@ public:
     void submit_command_and_output (CommandAndOutput &a_cao);
 };//end class OutputHandlerList
 
-
 NEMIVER_END_NAMESPACE (nemiver)
 
 #endif //__NMV_DBG_COMMON_H_H__
