@@ -23,8 +23,8 @@
  *
  *See COPYRIGHT file copyright information.
  */
-#ifndef __NEMIVER_I_DEBUGGER_H__
-#define __NEMIVER_I_DEBUGGER_H__
+#ifndef __NMV_I_DEBUGGER_H__
+#define __NMV_I_DEBUGGER_H__
 
 #include <stdint.h>
 #include <vector>
@@ -160,7 +160,7 @@ public:
         bool is_write_watchpoint () const {return m_is_write_watchpoint;}
         void is_write_watchpoint (bool f) {m_is_write_watchpoint = f;}
 
-        bool is_pending ()
+        bool is_pending () const
         {
             if (m_address == "<PENDING>") {
                 return true;
@@ -345,7 +345,22 @@ public:
     typedef sigc::slot<void, const map<int, IDebugger::VariableList>& >
         FrameArgsSlot;
 
+    typedef sigc::slot<void, const VariableSafePtr> ConstVariableSlot;
+    typedef sigc::slot<void, const VariableList> ConstVariableListSlot;
+    typedef sigc::slot<void, const UString&> ConstUStringSlot;
+
     class Variable : public Object {
+    public:
+        enum Format {
+            UNDEFINED_FORMAT = 0,
+            BINARY_FORMAT,
+            DECIMAL_FORMAT,
+            HEXADECIMAL_FORMAT,
+            OCTAL_FORMAT,
+            NATURAL_FORMAT,
+            UNKNOWN_FORMAT // must be last
+        };
+    private:
         // non copyable.
         Variable (const Variable &);
         Variable& operator= (const Variable &);
@@ -362,6 +377,16 @@ public:
         UString m_name_caption;
         UString m_value;
         UString m_type;
+        // When using GDB pretty-printers, this is a string naming the
+        // pretty printer used to visualize this variable. As
+        // disabling pretty printing is not possible globally in GDB
+        // we need to use this even when the user doesn't want to
+        // change it.  Setting it to "" should do the right thing: if
+        // pretty printing is enabled, the variable will be displayed
+        // using  the default pretty printer; if pretty printing is
+        // disabled the variable would be displayed using no pretty
+        // printer.
+        UString m_visualizer;
         Variable *m_parent;
         //if this variable is a pointer,
         //it can be dereferenced. The variable
@@ -374,6 +399,8 @@ public:
         // IDebugger::query_variable_path_expr()
         UString m_path_expression;
         bool m_in_scope;
+        Format m_format;
+        bool m_needs_revisualizing;
 
     public:
         Variable (const UString &a_internal_name,
@@ -387,8 +414,9 @@ public:
             m_type (a_type),
             m_parent (0),
             m_num_expected_children (0),
-            m_in_scope (a_in_scope)
-
+            m_in_scope (a_in_scope),
+            m_format (UNDEFINED_FORMAT),
+            m_needs_revisualizing (false)
         {
         }
 
@@ -401,7 +429,9 @@ public:
             m_type (a_type),
             m_parent (0),
             m_num_expected_children (0),
-            m_in_scope (a_in_scope)
+            m_in_scope (a_in_scope),
+            m_format (UNDEFINED_FORMAT),
+            m_needs_revisualizing (false)
 
         {
         }
@@ -410,19 +440,25 @@ public:
             : m_name (a_name),
             m_parent (0),
             m_num_expected_children (0),
-            m_in_scope (true)
+            m_in_scope (true),
+            m_format (UNDEFINED_FORMAT),
+            m_needs_revisualizing (false)
                 
         {}
 
         Variable ()
             : m_parent (0),
             m_num_expected_children (0),
-            m_in_scope (true)
+            m_in_scope (true),
+            m_format (UNDEFINED_FORMAT),
+            m_needs_revisualizing (false)
                 
         {}
 
         const VariableList& members () const {return m_members;}
 
+        VariableList& members () {return m_members;}
+
         /// Returns the Nth member variable, if any.
         /// Please note that this function has O(n) complexity. So use it with
         /// care.
@@ -528,6 +564,9 @@ public:
         void type (const UString &a_type) {m_type = a_type;}
         void type (const string &a_type) {m_type = a_type;}
 
+        const UString& visualizer () const {return m_visualizer;}
+        void visualizer (const UString &a) {m_visualizer = a;}
+
         /// Return true if this instance of Variable has a parent variable,
         /// false otherwise.
         bool has_parent () const
@@ -766,6 +805,12 @@ public:
         bool in_scope () const {return m_in_scope;}
         void in_scope (bool a) {m_in_scope = a;}
 
+        Format format () const {return m_format;}
+        void format (Format a_format) {m_format = a_format;}
+
+        bool needs_revisualizing () const {return m_needs_revisualizing;}
+        void needs_revisualizing (bool a) {m_needs_revisualizing = a;}
+
     };//end class Variable
 
     enum State {
@@ -877,9 +922,9 @@ public:
                                          breakpoints_list_signal () const=0;
 
     virtual sigc::signal<void,
-                        const std::pair<int, const IDebugger::Breakpoint&>&,
+                        const std::map<int, IDebugger::Breakpoint>&,
                         const UString& /*cookie*/>&
-                        breakpoint_set_signal () const = 0;
+                        breakpoints_set_signal () const = 0;
 
     virtual sigc::signal<void,
                          const vector<OverloadsChoiceEntry>&,
@@ -968,6 +1013,9 @@ public:
                          const UString&/*cookie*/>&
                                       variable_dereferenced_signal () const=0;
 
+    sigc::signal<void, const VariableSafePtr, const UString&>&
+      variable_visualized_signal () const;
+
     virtual sigc::signal<void, const vector<UString>&, const UString&>&
                             files_listed_signal () const = 0;
 
@@ -1140,7 +1188,7 @@ public:
     virtual void set_breakpoint (const common::Loc &a_loc,
                                  const UString &a_condition,
                                  gint a_ignore_count,
-                                 const BreakpointSlot &a_slot,
+                                 const BreakpointsSlot &a_slot,
                                  const UString &a_cookie = "") = 0;
 
     virtual void set_breakpoint (const UString &a_path,
@@ -1271,6 +1319,9 @@ public:
     virtual bool dereference_variable (const VariableSafePtr &a_var,
                                        const UString &a_cookie="") = 0;
 
+    virtual void revisualize_variable (const VariableSafePtr a_var,
+                                       const ConstVariableSlot &a_slot) = 0;
+
     virtual void list_files (const UString &a_cookie="") = 0;
 
     virtual void list_register_names (const UString &a_cookie="") = 0;
@@ -1320,10 +1371,6 @@ public:
                                     bool a_pure_asm = true,
                                     const UString &a_cookie = "") = 0;
 
-    typedef sigc::slot<void, const VariableSafePtr> ConstVariableSlot;
-    typedef sigc::slot<void, const VariableList> ConstVariableListSlot;
-    typedef sigc::slot<void, const UString&> ConstUStringSlot;
-
     virtual void create_variable (const UString &a_name,
                                   const UString &a_cookie = "") = 0;
 
@@ -1371,13 +1418,24 @@ public:
 
     virtual void query_variable_path_expr (const VariableSafePtr a_var,
                                            const UString &a_cookie = "") = 0;
+
     virtual void query_variable_path_expr (const VariableSafePtr a_var,
                                            const ConstVariableSlot &a_slot,
                                            const UString &a_cookie = "") = 0;
 
+    virtual void query_variable_format (const VariableSafePtr a_var,
+                                        const ConstVariableSlot &a_slot,
+                                        const UString &a_cookie = "") = 0;
+
+    virtual void set_variable_format (const VariableSafePtr a_var,
+                                      const Variable::Format a_format,
+                                      const UString &a_cookie = "") = 0;
+
+    virtual void enable_pretty_printing (bool a_flag = true) = 0;
+
 };//end IDebugger
 
 NEMIVER_END_NAMESPACE (nemiver)
 
-#endif //__NEMIVER_I_DEBUGGER_H__
+#endif //__NMV_I_DEBUGGER_H__
 
