@@ -101,7 +101,7 @@ Lexer::~Lexer ()
 {
     if (m_priv) {
         delete m_priv;
-        m_priv = NULL;
+        m_priv = 0;
     }
 }
 
