@@ -117,22 +117,23 @@ public:
     {
         init_actions ();
         build_tree_view ();
-        void set_breakpoints
-                (const std::map<int, IDebugger::Breakpoint> &a_breakpoints);
 
         // update breakpoint list when debugger indicates that the list of
         // breakpoints has changed.
         debugger->breakpoint_deleted_signal ().connect (sigc::mem_fun
                 (*this, &Priv::on_debugger_breakpoint_deleted_signal));
-        debugger->breakpoints_set_signal ().connect (sigc::mem_fun
-                (*this, &Priv::on_debugger_breakpoints_set_signal));
+        debugger->breakpoints_set_signal ().connect
+            (sigc::mem_fun (*this, &Priv::on_debugger_breakpoints_set_signal));
+        debugger->breakpoints_list_signal ().connect (sigc::mem_fun
+                (*this, &Priv::on_debugger_breakpoints_list_signal));
         debugger->stopped_signal ().connect (sigc::mem_fun
                 (*this, &Priv::on_debugger_stopped_signal));
         breakpoints_menu = load_menu ("breakpointspopup.xml",
                 "/BreakpointsPopup");
     }
 
-    void build_tree_view ()
+    void
+    build_tree_view ()
     {
         if (tree_view) {return;}
         //create a default tree store and a tree view
@@ -156,8 +157,9 @@ public:
         tree_view->append_column (_("Hits"), get_bp_cols ().hits);
         tree_view->append_column (_("Expression"),
                                   get_bp_cols ().expression);
-        nb_columns = tree_view->append_column_editable (_("Ignore count"),
-							get_bp_cols ().ignore_count);
+        nb_columns =
+            tree_view->append_column_editable (_("Ignore count"),
+                                               get_bp_cols ().ignore_count);
 	
 	for (int i = 0; i < nb_columns; ++i) {
             Gtk::TreeViewColumn *col = tree_view->get_column (i);
@@ -210,23 +212,26 @@ public:
 	  (sigc::mem_fun
 	   (*this, &Priv::on_treeview_selection_changed));
 
-        tree_view->signal_key_press_event ().connect (sigc::mem_fun
-                                                      (*this, &Priv::on_key_press_event));
-        tree_view->signal_expose_event ().connect_notify (sigc::mem_fun
-                                                          (*this, &Priv::on_expose_event));
+        tree_view->signal_key_press_event ().connect
+            (sigc::mem_fun
+             (*this, &Priv::on_key_press_event));
+        tree_view->signal_draw ().connect_notify
+            (sigc::mem_fun
+             (*this, &Priv::on_draw_signal));
     }
 
-    bool should_process_now ()
+    bool 
+    should_process_now ()
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD;
         THROW_IF_FAIL (tree_view);
-        bool is_visible = tree_view->is_drawable ();
+        bool is_visible = tree_view->get_is_drawable ();
         LOG_DD ("is visible: " << is_visible);
         return is_visible;
     }
 
-    void set_breakpoints
-        (const std::map<int, IDebugger::Breakpoint> &a_breakpoints)
+    void
+    set_breakpoints (const std::map<int, IDebugger::Breakpoint> &a_breakpoints)
     {
         if (a_breakpoints.empty ()) {
             return;
@@ -249,16 +254,29 @@ public:
                             << breakmap_iter->second.number ());
                     update_breakpoint (tree_iter, breakmap_iter->second);
                 } else {
-                    LOG_DD ("Adding breakpoint "
-                            << breakmap_iter->second.number ());
+                    // Normally, we shouldn't reach this place, as we
+                    // should have been notified about any new
+                    // breakpoint by mean of
+                    // IDebugger::breakpoint_set_signal, and
+                    // on_debugger_breakpoint_set_signal should have
+                    // added the breakpoint to the model.  It turned
+                    // out we can reach this point nevertheless, when,
+                    // say, a breakpoint is added by mean of a GDB
+                    // script. In that case, the GDB implementation of
+                    // IDebugger doesn't get any GDB/MI notification
+                    // upon breakpoint creation, so we don't get the
+                    // IDebugger::breakpoint_set_signal notification.
+                    // Let's just add the breakpoint now then.
+                    LOG_DD ("Didn't find breakpoint: " << breakmap_iter->first
+                            << " so going to add it");
                     append_breakpoint (breakmap_iter->second);
                 }
             }
         }
     }
 
-    void add_breakpoints
-                (const std::map<int, IDebugger::Breakpoint> &a_breakpoints)
+    void
+    add_breakpoints (const std::map<int, IDebugger::Breakpoint> &a_breakpoints)
     {
         THROW_IF_FAIL (list_store);
 
@@ -270,7 +288,8 @@ public:
         }
     }
 
-    bool breakpoint_list_has_id
+    bool
+    breakpoint_list_has_id
         (const std::map<int, IDebugger::Breakpoint> &a_breakpoints,
          int a_id)
     {
@@ -284,8 +303,8 @@ public:
         return false;
     }
 
-    Gtk::TreeModel::iterator find_breakpoint_in_model
-                                (const IDebugger::Breakpoint &a_breakpoint)
+    Gtk::TreeModel::iterator
+    find_breakpoint_in_model (const IDebugger::Breakpoint &a_breakpoint)
     {
         THROW_IF_FAIL (list_store);
 
@@ -301,8 +320,9 @@ public:
         return Gtk::TreeModel::iterator();
     }
 
-    void update_breakpoint (Gtk::TreeModel::iterator& a_iter,
-                            const IDebugger::Breakpoint &a_breakpoint)
+    void
+    update_breakpoint (Gtk::TreeModel::iterator& a_iter,
+                       const IDebugger::Breakpoint &a_breakpoint)
     {
         (*a_iter)[get_bp_cols ().breakpoint] = a_breakpoint;
         (*a_iter)[get_bp_cols ().enabled] = a_breakpoint.enabled ();
@@ -339,8 +359,8 @@ public:
         (*a_iter)[get_bp_cols ().hits] = a_breakpoint.nb_times_hit ();
     }
 
-    Gtk::TreeModel::iterator append_breakpoint
-                                    (const IDebugger::Breakpoint &a_breakpoint)
+    Gtk::TreeModel::iterator 
+    append_breakpoint (const IDebugger::Breakpoint &a_breakpoint)
     {
         Gtk::TreeModel::iterator tree_iter = list_store->append ();
         update_breakpoint (tree_iter, a_breakpoint);
@@ -348,13 +368,15 @@ public:
         return tree_iter;
     }
 
-    void finish_handling_debugger_stopped_event ()
+    void
+    finish_handling_debugger_stopped_event ()
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD;
         debugger->list_breakpoints ();
     }
 
-    Gtk::Widget* load_menu (UString a_filename, UString a_widget_name)
+    Gtk::Widget*
+    load_menu (UString a_filename, UString a_widget_name)
     {
         NEMIVER_TRY
         string relative_path = Glib::build_filename ("menus", a_filename);
@@ -368,13 +390,15 @@ public:
         return workbench.get_ui_manager ()->get_widget (a_widget_name);
     }
 
-    Gtk::Widget* get_breakpoints_menu ()
+    Gtk::Widget*
+    get_breakpoints_menu ()
     {
         THROW_IF_FAIL (breakpoints_menu);
         return breakpoints_menu;
     }
 
-    void popup_breakpoints_view_menu (GdkEventButton *a_event)
+    void
+    popup_breakpoints_view_menu (GdkEventButton *a_event)
     {
         THROW_IF_FAIL (a_event);
         THROW_IF_FAIL (tree_view);
@@ -383,7 +407,8 @@ public:
         menu->popup (a_event->button, a_event->time);
     }
 
-    void init_actions()
+    void
+    init_actions()
     {
         static ui_utils::ActionEntry s_breakpoints_action_entries [] = {
             {
@@ -431,7 +456,8 @@ public:
         debugger->list_breakpoints ();
     }
 
-    void erase_breakpoint (int a_bp_num)
+    void
+    erase_breakpoint (int a_bp_num)
     {
 
         LOG_DD ("asked to erase bp num:" << (int) a_bp_num);
@@ -451,7 +477,8 @@ public:
         }
     }
 
-    void on_debugger_breakpoints_set_signal
+    void 
+    on_debugger_breakpoints_list_signal
                             (const map<int, IDebugger::Breakpoint> &a_breaks,
                              const UString &a_cookie)
     {
@@ -461,12 +488,13 @@ public:
         NEMIVER_CATCH
     }
 
-    void on_debugger_stopped_signal (IDebugger::StopReason a_reason,
-                                     bool /*a_has_frame*/,
-                                     const IDebugger::Frame &/*a_frame*/,
-                                     int /*a_thread_id*/,
-                                     int a_bkpt_num,
-                                     const UString &/*a_cookie*/)
+    void
+    on_debugger_stopped_signal (IDebugger::StopReason a_reason,
+                                bool /*a_has_frame*/,
+                                const IDebugger::Frame &/*a_frame*/,
+                                int /*a_thread_id*/,
+                                int a_bkpt_num,
+                                const UString &/*a_cookie*/)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD;
 
@@ -491,9 +519,10 @@ public:
         NEMIVER_CATCH
     }
 
-    void on_debugger_breakpoint_deleted_signal
-            (const IDebugger::Breakpoint &a_break, int a_break_number,
-             const UString &a_cookie)
+    void
+    on_debugger_breakpoint_deleted_signal (const IDebugger::Breakpoint &a_break,
+                                           int a_break_number,
+                                           const UString &a_cookie)
     {
         if (a_break.number () || a_cookie.empty()) {}
         NEMIVER_TRY
@@ -515,7 +544,25 @@ public:
         NEMIVER_CATCH
     }
 
-    bool on_breakpoints_view_button_press_signal (GdkEventButton *a_event)
+    void
+    on_debugger_breakpoints_set_signal
+    (const std::map<int, IDebugger::Breakpoint> &a,
+     const UString &)
+    {
+        NEMIVER_TRY;
+
+        std::map<int, IDebugger::Breakpoint>::const_iterator i;
+        for (i = a.begin (); i != a.end (); ++i) {
+            LOG_DD ("Adding breakpoints "
+                    << i->second.number ());
+            append_breakpoint (i->second);
+        }
+
+        NEMIVER_CATCH;
+    }
+
+    bool
+    on_breakpoints_view_button_press_signal (GdkEventButton *a_event)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD;
         bool handled = false;
@@ -537,7 +584,7 @@ public:
                 // only pop up a context menu if there's a valid item at the
                 // point where the user clicked
                 Gtk::TreeModel::Path path;
-                Gtk::TreeViewColumn* p_column = NULL;
+                Gtk::TreeViewColumn* p_column = 0;
                 int cell_x=0, cell_y=0;
                 if (tree_view->get_path_at_pos (
                             static_cast<int>(a_event->x),
@@ -562,7 +609,8 @@ public:
         return handled;
     }
 
-    void on_treeview_selection_changed ()
+    void
+    on_treeview_selection_changed ()
     {
         NEMIVER_TRY
         THROW_IF_FAIL(tree_view)
@@ -584,7 +632,8 @@ public:
         NEMIVER_CATCH
     }
 
-    void on_breakpoint_go_to_source_action ()
+    void
+    on_breakpoint_go_to_source_action ()
     {
         THROW_IF_FAIL(tree_view)
         Glib::RefPtr<Gtk::TreeSelection> selection =
@@ -599,7 +648,8 @@ public:
         }
     }
 
-    void on_breakpoint_delete_action ()
+    void
+    on_breakpoint_delete_action ()
     {
         THROW_IF_FAIL (tree_view)
         THROW_IF_FAIL (list_store);
@@ -618,7 +668,8 @@ public:
         }
     }
 
-    void on_expose_event (GdkEventExpose *)
+    void
+    on_draw_signal (const Cairo::RefPtr<Cairo::Context> &)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD;
         NEMIVER_TRY
@@ -629,16 +680,18 @@ public:
         NEMIVER_CATCH
     }
 
-    bool on_key_press_event (GdkEventKey* event)
+    bool 
+    on_key_press_event (GdkEventKey* event)
     {
-        if (event && event->keyval == GDK_Delete)
+        if (event && event->keyval == GDK_KEY_Delete)
         {
             on_breakpoint_delete_action ();
         }
         return false;
     }
 
-    void on_breakpoint_enable_toggled (const Glib::ustring& path)
+    void
+    on_breakpoint_enable_toggled (const Glib::ustring& path)
     {
         NEMIVER_TRY
 
@@ -658,7 +711,8 @@ public:
         NEMIVER_CATCH
     }
 
-    void on_countpoint_toggled (const Glib::ustring& path)
+    void
+    on_countpoint_toggled (const Glib::ustring& path)
     {
         NEMIVER_TRY;
 
@@ -678,8 +732,9 @@ public:
         NEMIVER_CATCH;
     }
 
-    void on_breakpoint_ignore_count_edited (const Glib::ustring &a_path,
-                                            const Glib::ustring &a_text)
+    void 
+    on_breakpoint_ignore_count_edited (const Glib::ustring &a_path,
+                                       const Glib::ustring &a_text)
     {
         NEMIVER_TRY
 
@@ -706,8 +761,9 @@ public:
         NEMIVER_CATCH
     }
 
-    void on_breakpoint_condition_edited (const Glib::ustring &a_path,
-                                         const Glib::ustring &a_text)
+    void
+    on_breakpoint_condition_edited (const Glib::ustring &a_path,
+                                    const Glib::ustring &a_text)
     {
         NEMIVER_TRY
 
