@@ -25,17 +25,17 @@
 #include <glib/gi18n.h>
 #include <gtkmm/treeview.h>
 #include <gtkmm/liststore.h>
+#include "common/nmv-env.h"
 #include "nmv-preferences-dialog.h"
 #include "nmv-ui-utils.h"
 #include "nmv-i-conf-mgr.h"
-#include "nmv-i-workbench.h"
+#include "nmv-i-perspective.h"
 #include "nmv-conf-keys.h"
-#ifdef WITH_SOURCEVIEWMM2
-#include <gtksourceviewmm/sourcestyleschememanager.h>
-#endif
+#include "nmv-layout-selector.h"
+#include <gtksourceviewmm/styleschememanager.h>
 
 using nemiver::common::DynamicModuleManager;
-
+static const std::string DEFAULT_GDB_BINARY = "default-gdb-binary";
 NEMIVER_BEGIN_NAMESPACE(nemiver)
 
 struct SourceDirsCols : public Gtk::TreeModelColumnRecord {
@@ -65,7 +65,8 @@ class PreferencesDialog::Priv {
     };
 
 public:
-    IWorkbench &workbench;
+    IPerspective &perspective;
+    LayoutManager &layout_manager;
     //source directories property widgets
     vector<UString> source_dirs;
     Glib::RefPtr<Gtk::ListStore> list_store;
@@ -76,33 +77,53 @@ public:
     Gtk::CheckButton *system_font_check_button;
     Gtk::FontButton *custom_font_button;
     Gtk::ComboBox *editor_style_combo;
+    Gtk::ComboBoxText *asm_flavor_combo;
     Glib::RefPtr<Gtk::ListStore> m_editor_style_model;
     StyleModelColumns m_style_columns;
     Gtk::CellRendererText m_style_name_renderer;
     Gtk::HBox *custom_font_box;
+    Gtk::Box *layout_box;
     Gtk::CheckButton *show_lines_check_button;
     Gtk::CheckButton *launch_terminal_check_button;
     Gtk::CheckButton *highlight_source_check_button;
     Gtk::RadioButton *always_reload_radio_button;
     Gtk::RadioButton *never_reload_radio_button;
     Gtk::RadioButton *confirm_reload_radio_button;
-    Glib::RefPtr<Gnome::Glade::Xml> glade;
+    Gtk::RadioButton *pure_asm_radio_button;
+    Gtk::RadioButton *mixed_asm_radio_button;
+    Gtk::RadioButton *follow_parent_radio_button;
+    Gtk::RadioButton *follow_child_radio_button;
+    Gtk::SpinButton  *default_num_asm_instrs_spin_button;
+    Gtk::FileChooserButton *gdb_binary_path_chooser_button;
+    Gtk::CheckButton *pretty_printing_check_button;
+    Glib::RefPtr<Gtk::Builder> gtkbuilder;
+    SafePtr<LayoutSelector> layout_selector;
 
-    Priv (const Glib::RefPtr<Gnome::Glade::Xml> &a_glade,
-          IWorkbench &a_workbench) :
-        workbench (a_workbench),
+    Priv (const Glib::RefPtr<Gtk::Builder> &a_gtkbuilder,
+          IPerspective &a_perspective,
+          LayoutManager &a_layout_manager) :
+        perspective (a_perspective),
+        layout_manager (a_layout_manager),
         tree_view (0),
         remove_dir_button (0),
         system_font_check_button (0),
         custom_font_button (0),
         custom_font_box (0),
+        layout_box (0),
         show_lines_check_button (0),
         launch_terminal_check_button (0),
         highlight_source_check_button (0),
         always_reload_radio_button (0),
         never_reload_radio_button (0),
         confirm_reload_radio_button (0),
-        glade (a_glade)
+        pure_asm_radio_button (0),
+        mixed_asm_radio_button (0),
+        follow_parent_radio_button (0),
+        follow_child_radio_button (0),
+        default_num_asm_instrs_spin_button (0),
+        gdb_binary_path_chooser_button (0),
+        pretty_printing_check_button (0),
+        gtkbuilder (a_gtkbuilder)
     {
         init ();
     }
@@ -188,17 +209,51 @@ public:
         update_editor_style_key ();
     }
 
+    void on_asm_flavor_changed_signal ()
+    {
+        update_asm_flavor_key ();
+    }
+
     void on_reload_files_toggled_signal ()
     {
         update_reload_files_keys ();
     }
 
+    void on_asm_style_toggled_signal ()
+    {
+        update_asm_style_keys ();
+    }
+
+    void on_num_asms_value_changed_signal ()
+    {
+        update_default_num_asm_instrs_key ();
+    }
+
+    void on_gdb_binary_file_set_signal ()
+    {
+        update_gdb_binary_key ();
+    }
+
+    void on_follow_fork_mode_toggle_signal ()
+    {
+        update_follow_fork_mode_key ();
+    }
+
+    void on_pretty_printing_toggled_signal ()
+    {
+        update_pretty_printing_key ();
+    }
+
     void init ()
     {
 
+        // ********************************************
+        // Handle the sources directory preferences tab
+        // ********************************************
+
         list_store = Gtk::ListStore::create (source_dirs_cols ());
         tree_view =
-            ui_utils::get_widget_from_glade<Gtk::TreeView> (glade,
+            ui_utils::get_widget_from_gtkbuilder<Gtk::TreeView> (gtkbuilder,
                                                             "dirstreeview");
         tree_view->append_column (_("Source directories"),
                                   source_dirs_cols ().dir);
@@ -214,22 +269,26 @@ public:
          (this, &PreferencesDialog::Priv::on_tree_view_selection_changed));
 
         Gtk::Button *button =
-            ui_utils::get_widget_from_glade<Gtk::Button> (glade,
+            ui_utils::get_widget_from_gtkbuilder<Gtk::Button> (gtkbuilder,
                                                           "adddirbutton");
         button->signal_clicked ().connect (sigc::mem_fun
                 (this, &PreferencesDialog::Priv::on_add_dir_button_clicked));
 
         remove_dir_button =
-        ui_utils::get_widget_from_glade<Gtk::Button> (glade,
+        ui_utils::get_widget_from_gtkbuilder<Gtk::Button> (gtkbuilder,
                                                       "suppressdirbutton");
         remove_dir_button->signal_clicked ().connect
         (sigc::mem_fun
             (this, &PreferencesDialog::Priv::on_remove_dir_button_clicked));
         remove_dir_button->set_sensitive (false);
 
+        // *************************************
+        // Handle the "Editor" preference tab
+        // *************************************
+
         show_lines_check_button  =
-            ui_utils::get_widget_from_glade<Gtk::CheckButton>
-                                            (glade, "showlinescheckbutton");
+            ui_utils::get_widget_from_gtkbuilder<Gtk::CheckButton>
+                                            (gtkbuilder, "showlinescheckbutton");
         THROW_IF_FAIL (show_lines_check_button);
         show_lines_check_button->signal_toggled ().connect
         (sigc::mem_fun
@@ -237,8 +296,8 @@ public:
              &PreferencesDialog::Priv::on_show_lines_toggled_signal));
 
         launch_terminal_check_button  =
-            ui_utils::get_widget_from_glade<Gtk::CheckButton>
-                                            (glade, "launchterminalcheckbutton");
+            ui_utils::get_widget_from_gtkbuilder<Gtk::CheckButton>
+                                            (gtkbuilder, "launchterminalcheckbutton");
         THROW_IF_FAIL (launch_terminal_check_button);
         launch_terminal_check_button->signal_toggled ().connect
         (sigc::mem_fun
@@ -246,8 +305,8 @@ public:
              &PreferencesDialog::Priv::on_launch_terminal_toggled_signal));
 
         highlight_source_check_button  =
-            ui_utils::get_widget_from_glade<Gtk::CheckButton>
-                                    (glade, "highlightsourcecheckbutton");
+            ui_utils::get_widget_from_gtkbuilder<Gtk::CheckButton>
+                                    (gtkbuilder, "highlightsourcecheckbutton");
         THROW_IF_FAIL (highlight_source_check_button);
         highlight_source_check_button->signal_toggled ().connect
         (sigc::mem_fun
@@ -255,8 +314,8 @@ public:
              &PreferencesDialog::Priv::on_highlight_source_toggled_signal));
 
         system_font_check_button =
-            ui_utils::get_widget_from_glade<Gtk::CheckButton>
-            (glade, "systemfontcheckbutton");
+            ui_utils::get_widget_from_gtkbuilder<Gtk::CheckButton>
+            (gtkbuilder, "systemfontcheckbutton");
         THROW_IF_FAIL (system_font_check_button);
         system_font_check_button->signal_toggled ().connect
         (sigc::mem_fun
@@ -264,8 +323,8 @@ public:
              &PreferencesDialog::Priv::on_system_font_toggled_signal));
 
         custom_font_button =
-            ui_utils::get_widget_from_glade<Gtk::FontButton>
-            (glade, "customfontfontbutton");
+            ui_utils::get_widget_from_gtkbuilder<Gtk::FontButton>
+            (gtkbuilder, "customfontfontbutton");
         THROW_IF_FAIL (custom_font_button);
         custom_font_button->signal_font_set ().connect
         (sigc::mem_fun
@@ -273,25 +332,25 @@ public:
              &PreferencesDialog::Priv::on_custom_font_set_signal));
 
         custom_font_box =
-            ui_utils::get_widget_from_glade<Gtk::HBox>
-            (glade, "customfonthbox");
+            ui_utils::get_widget_from_gtkbuilder<Gtk::HBox>
+            (gtkbuilder, "customfonthbox");
         THROW_IF_FAIL (custom_font_box);
 
         editor_style_combo =
-            ui_utils::get_widget_from_glade<Gtk::ComboBox>
-                                                        (glade,
+            ui_utils::get_widget_from_gtkbuilder<Gtk::ComboBox>
+                                                        (gtkbuilder,
                                                          "editorstylecombobox");
         THROW_IF_FAIL (editor_style_combo);
         m_editor_style_model = Gtk::ListStore::create (m_style_columns);
-#ifdef WITH_SOURCEVIEWMM2
-        Glib::RefPtr<gtksourceview::SourceStyleSchemeManager> mgr =
-            gtksourceview::SourceStyleSchemeManager::get_default ();
-        std::list<Glib::ustring> schemes = mgr->get_scheme_ids ();
-        for (std::list<Glib::ustring>::const_iterator it = schemes.begin ();
+
+        Glib::RefPtr<Gsv::StyleSchemeManager> mgr =
+            Gsv::StyleSchemeManager::get_default ();
+        std::vector<std::string> schemes = mgr->get_scheme_ids ();
+        for (std::vector<std::string>::const_iterator it = schemes.begin ();
              it != schemes.end(); ++it) {
             Gtk::TreeModel::iterator treeiter = m_editor_style_model->append ();
             (*treeiter)[m_style_columns.scheme_id] = *it;
-            Glib::RefPtr<gtksourceview::SourceStyleScheme> scheme =
+            Glib::RefPtr<Gsv::StyleScheme> scheme =
                 mgr->get_scheme (*it);
             (*treeiter)[m_style_columns.name] =
                 Glib::ustring::compose ("%1 - <span size=\"smaller\" "
@@ -307,20 +366,10 @@ public:
         editor_style_combo->signal_changed ().connect (sigc::mem_fun
                     (*this,
                      &PreferencesDialog::Priv::on_editor_style_changed_signal));
-#else
-        Gtk::TreeModel::iterator treeiter = m_editor_style_model->append ();
-        (*treeiter)[m_style_columns.name] =
-                                Glib::ustring ("Only available "
-                                               "with gtksourceviewmm2");
-        editor_style_combo->set_model (m_editor_style_model);
-        editor_style_combo->pack_start (m_style_columns.name);
-        editor_style_combo->set_active (treeiter);
-        editor_style_combo->set_sensitive (false);
-#endif // WITH_SOURCEVIEWMM2
 
         always_reload_radio_button =
-            ui_utils::get_widget_from_glade<Gtk::RadioButton>
-                                                        (glade,
+            ui_utils::get_widget_from_gtkbuilder<Gtk::RadioButton>
+                                                        (gtkbuilder,
                                                          "reloadradiobutton");
         THROW_IF_FAIL (always_reload_radio_button);
         always_reload_radio_button->signal_toggled ().connect (sigc::mem_fun
@@ -328,8 +377,8 @@ public:
                      &PreferencesDialog::Priv::on_reload_files_toggled_signal));
 
         never_reload_radio_button =
-            ui_utils::get_widget_from_glade<Gtk::RadioButton>
-                                                (glade,
+            ui_utils::get_widget_from_gtkbuilder<Gtk::RadioButton>
+                                                (gtkbuilder,
                                                  "neverreloadradiobutton");
         THROW_IF_FAIL (never_reload_radio_button);
         never_reload_radio_button->signal_toggled ().connect (sigc::mem_fun
@@ -337,12 +386,102 @@ public:
              &PreferencesDialog::Priv::on_reload_files_toggled_signal));
 
         confirm_reload_radio_button =
-            ui_utils::get_widget_from_glade<Gtk::RadioButton>
-            (glade, "confirmreloadradiobutton");
+            ui_utils::get_widget_from_gtkbuilder<Gtk::RadioButton>
+            (gtkbuilder, "confirmreloadradiobutton");
         THROW_IF_FAIL (confirm_reload_radio_button);
         confirm_reload_radio_button->signal_toggled ().connect (sigc::mem_fun
             (*this,
              &PreferencesDialog::Priv::on_reload_files_toggled_signal));
+
+        // *************************************
+        // Handle the "Debugger" preferences tab
+        // *************************************
+
+        pure_asm_radio_button =
+            ui_utils::get_widget_from_gtkbuilder<Gtk::RadioButton>
+                (gtkbuilder, "pureasmradio");
+        THROW_IF_FAIL (pure_asm_radio_button);
+        pure_asm_radio_button->signal_toggled ().connect
+            (sigc::mem_fun
+                 (*this,
+                  &PreferencesDialog::Priv::on_asm_style_toggled_signal));
+
+        asm_flavor_combo =
+            ui_utils::get_widget_from_gtkbuilder<Gtk::ComboBoxText>
+                (gtkbuilder, "asmflavorcombobox");
+        THROW_IF_FAIL (asm_flavor_combo);
+        asm_flavor_combo->signal_changed ().connect (sigc::mem_fun
+                    (*this,
+                     &PreferencesDialog::Priv::on_asm_flavor_changed_signal));
+        asm_flavor_combo->set_entry_text_column (0);
+
+        mixed_asm_radio_button =
+            ui_utils::get_widget_from_gtkbuilder<Gtk::RadioButton>
+                (gtkbuilder, "mixedasmradio");
+        THROW_IF_FAIL (mixed_asm_radio_button);
+        mixed_asm_radio_button->signal_toggled ().connect
+            (sigc::mem_fun
+                 (*this,
+                  &PreferencesDialog::Priv::on_asm_style_toggled_signal));
+
+        default_num_asm_instrs_spin_button =
+            ui_utils::get_widget_from_gtkbuilder<Gtk::SpinButton>
+                (gtkbuilder, "defaultnumasmspin");
+        THROW_IF_FAIL (default_num_asm_instrs_spin_button);
+        default_num_asm_instrs_spin_button->signal_value_changed ().connect
+            (sigc::mem_fun
+                 (*this,
+                  &PreferencesDialog::Priv::on_num_asms_value_changed_signal));
+
+        gdb_binary_path_chooser_button =
+        ui_utils::get_widget_from_gtkbuilder<Gtk::FileChooserButton>
+                (gtkbuilder, "pathtogdbfilechooser");
+        THROW_IF_FAIL (gdb_binary_path_chooser_button);
+        gdb_binary_path_chooser_button->signal_file_set ().connect
+            (sigc::mem_fun
+                 (*this,
+                  &PreferencesDialog::Priv::on_gdb_binary_file_set_signal));
+
+        follow_parent_radio_button =
+        ui_utils::get_widget_from_gtkbuilder<Gtk::RadioButton> (gtkbuilder,
+                                                           "followparentradio");
+        THROW_IF_FAIL (follow_parent_radio_button);
+        follow_parent_radio_button->signal_toggled ().connect
+            (sigc::mem_fun
+                 (*this,
+                  &PreferencesDialog::Priv::on_follow_fork_mode_toggle_signal));
+
+        follow_child_radio_button =
+        ui_utils::get_widget_from_gtkbuilder<Gtk::RadioButton> (gtkbuilder,
+                                                           "followchildradio");
+        THROW_IF_FAIL (follow_child_radio_button);
+        follow_child_radio_button->signal_toggled ().connect
+            (sigc::mem_fun
+                 (*this,
+                  &PreferencesDialog::Priv::on_follow_fork_mode_toggle_signal));
+
+        pretty_printing_check_button =
+            ui_utils::get_widget_from_gtkbuilder<Gtk::CheckButton>
+            (gtkbuilder,
+             "prettyprintingcheckbutton");
+        THROW_IF_FAIL (pretty_printing_check_button);
+        pretty_printing_check_button->signal_toggled ().connect
+            (sigc::mem_fun
+             (*this,
+              &PreferencesDialog::Priv::on_pretty_printing_toggled_signal));
+
+
+        // *************************************
+        // Handle the "Layout" preferences tab
+        // *************************************
+
+        layout_box = ui_utils::get_widget_from_gtkbuilder<Gtk::Box>
+            (gtkbuilder, "layoutbox");
+        THROW_IF_FAIL (layout_box);
+
+        layout_selector.reset (new LayoutSelector (layout_manager, perspective));
+        layout_box->pack_start (layout_selector->widget ());
+        layout_box->show_all_children ();                                    
     }
 
     void collect_source_dirs ()
@@ -370,7 +509,8 @@ public:
 
     IConfMgr& conf_manager () const
     {
-        IConfMgrSafePtr conf_mgr = workbench.get_configuration_manager ();
+        IConfMgrSafePtr conf_mgr = perspective.get_workbench ()
+            .get_configuration_manager ();
         THROW_IF_FAIL (conf_mgr);
         return *conf_mgr;
     }
@@ -454,6 +594,19 @@ public:
                     (CONF_KEY_EDITOR_STYLE_SCHEME, scheme);
     }
 
+    void update_asm_flavor_key ()
+    {
+        THROW_IF_FAIL (asm_flavor_combo);
+        UString asm_flavor = asm_flavor_combo->get_active_text ();
+        if (asm_flavor == "Intel") {
+            conf_manager ().set_key_value
+                    (CONF_KEY_DISASSEMBLY_FLAVOR, Glib::ustring ("intel"));
+        } else {
+            conf_manager ().set_key_value
+                    (CONF_KEY_DISASSEMBLY_FLAVOR, Glib::ustring ("att"));
+        }
+    }
+
     void update_reload_files_keys ()
     {
         THROW_IF_FAIL (always_reload_radio_button);
@@ -476,6 +629,60 @@ public:
         }
     }
 
+    void update_asm_style_keys ()
+    {
+        THROW_IF_FAIL (pure_asm_radio_button);
+        THROW_IF_FAIL (mixed_asm_radio_button);
+
+        if (pure_asm_radio_button->get_active ()) {
+            conf_manager ().set_key_value (CONF_KEY_ASM_STYLE_PURE, true);
+        } else if (mixed_asm_radio_button->get_active ()) {
+            conf_manager ().set_key_value (CONF_KEY_ASM_STYLE_PURE, false);
+        }
+    }
+
+    void update_default_num_asm_instrs_key ()
+    {
+        THROW_IF_FAIL (default_num_asm_instrs_spin_button);
+        int num = default_num_asm_instrs_spin_button->get_value_as_int ();
+        conf_manager ().set_key_value (CONF_KEY_DEFAULT_NUM_ASM_INSTRS,
+                                       num);
+    }
+
+    void update_gdb_binary_key ()
+    {
+        THROW_IF_FAIL (gdb_binary_path_chooser_button);
+        UString path = gdb_binary_path_chooser_button->get_filename ();
+        if (path.empty ())
+            return;
+        if (path == DEFAULT_GDB_BINARY)
+            path = common::env::get_gdb_program ();
+        conf_manager ().set_key_value (CONF_KEY_GDB_BINARY,
+                                       Glib::filename_from_utf8 (path));
+    }
+
+    void update_follow_fork_mode_key ()
+    {
+        THROW_IF_FAIL (follow_parent_radio_button);
+        THROW_IF_FAIL (follow_child_radio_button);
+
+        UString mode = "parent";
+        if (follow_parent_radio_button->get_active ())
+            /*mode = "parent"*/;
+        else if (follow_child_radio_button->get_active ())
+            mode = "child";
+
+        conf_manager ().set_key_value (CONF_KEY_FOLLOW_FORK_MODE, mode);
+    }
+
+    void update_pretty_printing_key ()
+    {
+        THROW_IF_FAIL (pretty_printing_check_button);
+        
+        bool is_on = pretty_printing_check_button->get_active ();
+        conf_manager ().set_key_value (CONF_KEY_PRETTY_PRINTING, is_on);
+    }
+
     void update_widget_from_editor_keys ()
     {
         THROW_IF_FAIL (show_lines_check_button);
@@ -485,6 +692,7 @@ public:
         THROW_IF_FAIL (custom_font_button);
         THROW_IF_FAIL (custom_font_box);
         THROW_IF_FAIL (editor_style_combo);
+        THROW_IF_FAIL (asm_flavor_combo);
 
         bool is_on = true;
         if (!conf_manager ().get_key_value
@@ -541,6 +749,18 @@ public:
             }
         }
 
+        UString asm_flavor;
+        if (!conf_manager ().get_key_value
+                (CONF_KEY_DISASSEMBLY_FLAVOR, asm_flavor)) {
+            LOG_ERROR ("failed to get gconf key");
+        } else {
+            if (asm_flavor == "intel") {
+                asm_flavor_combo->set_active_text ("Intel");
+            } else {
+                asm_flavor_combo->set_active_text ("ATT");
+            }
+        }
+
         bool confirm_reload = true, always_reload = false;
         if (!conf_manager ().get_key_value
                 (CONF_KEY_CONFIRM_BEFORE_RELOAD_SOURCE, confirm_reload)) {
@@ -559,20 +779,75 @@ public:
         }
     }
 
+    void update_widget_from_debugger_keys ()
+    {
+        THROW_IF_FAIL (pure_asm_radio_button);
+        THROW_IF_FAIL (mixed_asm_radio_button);
+        THROW_IF_FAIL (default_num_asm_instrs_spin_button);
+        THROW_IF_FAIL (gdb_binary_path_chooser_button);
+
+        bool pure_asm = false;
+        if (!conf_manager ().get_key_value (CONF_KEY_ASM_STYLE_PURE,
+                                            pure_asm)) {
+            LOG_ERROR ("failed to get gconf key " << CONF_KEY_ASM_STYLE_PURE);
+        }
+        if (pure_asm)
+            pure_asm_radio_button->set_active ();
+        else
+            mixed_asm_radio_button->set_active ();
+
+        int num_asms = 25;
+        if (!conf_manager ().get_key_value (CONF_KEY_DEFAULT_NUM_ASM_INSTRS,
+                                            num_asms)) {
+            LOG_ERROR ("failed to get gconf key "
+                       << CONF_KEY_DEFAULT_NUM_ASM_INSTRS);
+        }
+        default_num_asm_instrs_spin_button->set_value (num_asms);
+
+        UString gdb_binary = common::env::get_gdb_program ();
+        if (!conf_manager ().get_key_value (CONF_KEY_GDB_BINARY, gdb_binary)) {
+            LOG_ERROR ("failed to get gconf key " << CONF_KEY_GDB_BINARY);
+        }
+        gdb_binary_path_chooser_button->set_filename
+            (Glib::filename_to_utf8 (gdb_binary));
+
+        UString follow_fork_mode = "parent";
+        if (!conf_manager ().get_key_value (CONF_KEY_FOLLOW_FORK_MODE,
+                                           follow_fork_mode)) {
+            LOG_ERROR ("failed to get gconf key "
+                       << CONF_KEY_FOLLOW_FORK_MODE);
+        }
+        if (follow_fork_mode == "parent") {
+            follow_parent_radio_button->set_active (true);
+        } else if (follow_fork_mode == "child") {
+            follow_child_radio_button->set_active (true);
+        }
+
+        bool is_on = true;
+        if (!conf_manager ().get_key_value (CONF_KEY_PRETTY_PRINTING,
+                                            is_on)) {
+            LOG_ERROR ("failed to get gconf key "
+                       << CONF_KEY_PRETTY_PRINTING);
+        }
+        pretty_printing_check_button->set_active (is_on);
+    }
+
     void update_widget_from_conf ()
     {
         update_widget_from_source_dirs_key ();
         update_widget_from_editor_keys ();
+        update_widget_from_debugger_keys ();
     }
 };//end PreferencesDialog
 
-PreferencesDialog::PreferencesDialog (IWorkbench &a_workbench,
+PreferencesDialog::PreferencesDialog (IPerspective &a_perspective,
+                                      LayoutManager &a_layout_manager,
                                       const UString &a_root_path) :
     Dialog (a_root_path,
-            "preferencesdialog.glade",
+            "preferencesdialog.ui",
             "preferencesdialog")
 {
-    m_priv.reset (new Priv (glade (), a_workbench));
+    m_priv.reset (new Priv (gtkbuilder (), a_perspective, a_layout_manager));
     m_priv->update_widget_from_conf ();
 }
 
