@@ -27,11 +27,7 @@
 #include <vector>
 #include <iostream>
 #include <glib/gi18n.h>
-#ifdef WITH_GIO
 #include <giomm/init.h>
-#else
-#include <libgnomevfs/gnome-vfs-init.h>
-#endif // WITH_GIO
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/icontheme.h>
 #include "common/nmv-exception.h"
@@ -57,18 +53,11 @@ NEMIVER_BEGIN_NAMESPACE (nemiver)
 class WorkbenchStaticInit {
     WorkbenchStaticInit ()
     {
-#ifdef WITH_GIO
         Gio::init();
-#else
-        gnome_vfs_init ();
-#endif // WITH_GIO
     }
 
     ~WorkbenchStaticInit ()
     {
-#ifndef WITH_GIO
-        gnome_vfs_shutdown ();
-#endif  // WITH_GIO
     }
 
 public:
@@ -96,6 +85,7 @@ private:
     void on_about_menu_item_action ();
     void on_contents_menu_item_action ();
     void on_shutting_down_signal ();
+    void on_perspective_layout_changed_signal (IPerspectiveSafePtr);
     //************************
     //</slots (signal callbacks)>
     //************************
@@ -112,6 +102,7 @@ private:
                                Gtk::Widget *a_body);
     bool remove_perspective_body (IPerspectiveSafePtr &a_perspective);
     void remove_all_perspective_bodies ();
+    void disconnect_all_perspective_signals ();
     void select_perspective (IPerspectiveSafePtr &a_perspective);
 
     void save_window_geometry ();
@@ -252,7 +243,7 @@ Workbench::on_contents_menu_item_action ()
     UString cmd_line ("yelp " + path_to_help);
     LOG_DD ("going to spawn: " << cmd_line);
     bool is_ok = g_spawn_command_line_async (Glib::locale_from_utf8
-                                             (cmd_line).c_str (), NULL);
+                                             (cmd_line).c_str (), 0);
     if (!is_ok) {
         LOG_ERROR ("failed to spawn " << is_ok);
     }
@@ -271,12 +262,12 @@ Workbench::on_about_menu_item_action ()
     dialog.set_version (PACKAGE_VERSION);
     dialog.set_comments(_("A C/C++ debugger for GNOME"));
 
-    list<Glib::ustring> authors;
+    vector<Glib::ustring> authors;
     authors.push_back ("Dodji Seketeli <dodji@gnome.org>");
     authors.push_back ("Jonathon Jongsma <jjongsma@gnome.org>");
     dialog.set_authors (authors);
 
-    list<Glib::ustring> documenters;
+    vector<Glib::ustring> documenters;
     documenters.push_back ("Jonathon Jongsma <jjongsma@gnome.org>");
     dialog.set_documenters (documenters);
 
@@ -340,6 +331,7 @@ Workbench::Workbench (DynamicModule *a_dynmod) :
 Workbench::~Workbench ()
 {
     remove_all_perspective_bodies ();
+    disconnect_all_perspective_signals ();
     LOG_D ("delete", "destructor-domain");
 }
 
@@ -386,7 +378,7 @@ Workbench::do_init (Gtk::Main &a_main)
         Glib::RefPtr<Gdk::Pixbuf> icon48 = theme->load_icon("nemiver", 48,
                 Gtk::ICON_LOOKUP_USE_BUILTIN);
 
-        std::list<Glib::RefPtr<Gdk::Pixbuf> > icon_list;
+        std::vector<Glib::RefPtr<Gdk::Pixbuf> > icon_list;
         icon_list.push_back(icon16);
         icon_list.push_back(icon32);
         icon_list.push_back(icon48);
@@ -432,6 +424,11 @@ Workbench::do_init (Gtk::Main &a_main)
                 if (perspective) {
                     m_priv->perspectives.push_front (perspective);
                     perspective->do_init (workbench);
+                    perspective->layout_changed_signal ().connect
+                        (sigc::bind<IPerspectiveSafePtr> (sigc::mem_fun
+                            (*this,
+                            &Workbench::on_perspective_layout_changed_signal),
+                        perspective));
                     perspective->edit_workbench_menu ();
                     toolbars.clear ();
                     perspective->get_toolbars (toolbars);
@@ -529,7 +526,7 @@ Workbench::get_perspective (const UString &a_name)
         }
     }
     LOG_ERROR ("could not find perspective: '" << a_name << "'");
-    return NULL;
+    return 0;
 }
 
 /// Set the configuration manager
@@ -825,6 +822,25 @@ Workbench::add_perspective_body (IPerspectiveSafePtr &a_perspective,
         m_priv->bodies_container->insert_page (*a_body, -1);
 }
 
+void
+Workbench::on_perspective_layout_changed_signal
+        (IPerspectiveSafePtr a_perspective)
+{
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
+
+    THROW_IF_FAIL (m_priv);
+    THROW_IF_FAIL (m_priv->bodies_container);
+
+    if (!a_perspective) {return;}
+
+    int page = m_priv->bodies_index_map[a_perspective.get ()];
+
+    m_priv->bodies_container->remove_page (page);
+    m_priv->bodies_container->insert_page (*a_perspective->get_body (), page);
+
+    select_perspective (a_perspective);
+}
+
 bool
 Workbench::remove_perspective_body (IPerspectiveSafePtr &a_perspective)
 {
@@ -891,6 +907,19 @@ Workbench::remove_all_perspective_bodies ()
     m_priv->bodies_index_map.clear ();
 }
 
+void
+Workbench::disconnect_all_perspective_signals ()
+{
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
+
+    list<IPerspectiveSafePtr>::iterator it;
+    for (it = m_priv->perspectives.begin ();
+         it != m_priv->perspectives.end ();
+         ++it) {
+        (*it)->layout_changed_signal ().clear ();
+    }
+}
+
 void
 Workbench::select_perspective (IPerspectiveSafePtr &a_perspective)
 {
