@@ -4,6 +4,7 @@
 #include "common/nmv-initializer.h"
 #include "common/nmv-safe-ptr-utils.h"
 #include "nmv-i-debugger.h"
+#include "nmv-debugger-utils.h"
 
 using namespace nemiver;
 using namespace nemiver::common;
@@ -44,7 +45,7 @@ on_variable_value_signal (const UString &a_variable_name,
     MESSAGE ("name of variable is: " << a_variable_name);
     BOOST_REQUIRE (a_variable_name == "i");
     MESSAGE ("variable value: " << a_var->value ());
-    BOOST_REQUIRE (a_var && a_var->value () == "0");
+    BOOST_REQUIRE (a_var && a_var->value () == "17");
 }
 
 void
@@ -77,9 +78,8 @@ test_main (int, char **)
     Initializer::do_init();
     THROW_IF_FAIL (loop);
 
-    DynamicModuleManager module_manager;
     IDebuggerSafePtr debugger =
-            module_manager.load_iface<IDebugger> ("gdbengine", "IDebugger");
+      debugger_utils::load_debugger_iface_with_confmgr ();
 
     debugger->set_event_loop_context (loop->get_context ());
 
@@ -96,16 +96,16 @@ test_main (int, char **)
 
     debugger->variable_value_signal ().connect (&on_variable_value_signal);
 
+    debugger->enable_pretty_printing (false);
     std::vector<UString> args, source_search_dir;
     source_search_dir.push_back (".");
 
-    debugger->load_program ("fooprog", args, ".", source_search_dir);
+    debugger->load_program ("fooprog", args, ".", source_search_dir, "", false);
     debugger->set_breakpoint ("func1");
+
     debugger->run ();
     loop->run ();
 
     NEMIVER_CATCH_NOX
     return 0;
 }
-
-
